/*******************************************************************************
DeskCalc. Copyright 1997-2000 Wunderbear Software. See below for license info.
$Id: $
Code Classification: C++, BeOS

This component implements the CalcOptionsWindow class, which provides a GUI
interface to allow the user to control the behaviour of the application.

Copyright (c) 1997-2000 Wunderbear Software. All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

1) Redistributions of source code must retain the above copyright notice, this
list of conditions and the following disclaimer.

2) Redistributions in binary form must reproduce the above copyright notice,
this list of conditions and the following disclaimer in the documentation and/or
other materials provided with the distribution.

3) Neither the name of the Wunderbear Software nor the names of its contributors
may be used to endorse or promote products derived from this software without
specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COMPANY OR CONTRIBUTORS BE LIABLE FOR ANY
DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*******************************************************************************/


#include "CalcOptionsWindow.h"


// Standard Includes

#include <stdlib.h>
#include <stdio.h>


// BeOS Includes

#ifndef _CHECK_BOX_H
	#include <interface/CheckBox.h>
#endif

#ifndef _BUTTON_H
	#include <interface/Button.h>
#endif


// Code!

/*******************************************************************************
<func>
Class:		CalcOptionsWindow
Function:	CalcOptionsWindow(BRect frame, CalcOptions *options);
Summary:	Constructor.
Params:	
Returns:	
Author:		timmy
Created:	1997.10.25
Notes:		-
History:
1997.10.27 timmy Changed parent from BWindow to RWindow.
1997.10.28 timmy Added CalcOptions parameter.
1998.10.20 timmy Reverted to using BWindow as base class.
</func>
*******************************************************************************/
CalcOptionsWindow::CalcOptionsWindow(BRect frame, CalcOptions *options)
	:	BWindow(frame, "Options", B_TITLED_WINDOW, 0),
		mAutoNumLockCheckBox(NULL),
		mAudioFeedbackCheckBox(NULL),
		mOkButton(NULL),
		mCancelButton(NULL),
		mOptions(options)
		{

	frame.OffsetTo(B_ORIGIN);
	frame.InsetBy(2.0f, 2.0f);

	// create interface components
	float y = 16.0f, vw, vh;
	BRect viewframe(4.0f, y, frame.right, y + 16.0f);
	mAutoNumLockCheckBox = new BCheckBox(viewframe,
		"autoNumLockCheckBox", "Auto Num Lock", NULL);
	if (mOptions->mAutoNumLock){
		mAutoNumLockCheckBox->SetValue(B_CONTROL_ON);
		} // end if
	AddChild(mAutoNumLockCheckBox);
	mAutoNumLockCheckBox->ResizeToPreferred();
	y = mAutoNumLockCheckBox->Frame().bottom;
	
	viewframe.Set(4.0f, y, frame.right, y + 16.0f);
	mAudioFeedbackCheckBox = new BCheckBox(viewframe,
		"audioFeedbackCheckBox", "Audio Feedback", NULL);
	if (mOptions->mAudioFeedback){
		mAudioFeedbackCheckBox->SetValue(B_CONTROL_ON);
		} // end if
	AddChild(mAudioFeedbackCheckBox);
	mAudioFeedbackCheckBox->ResizeToPreferred();
	y = mAudioFeedbackCheckBox->Frame().bottom;
	
	// create buttons
	viewframe.Set(0.0f, 0.0f, 40.0f, 40.0f);
	mOkButton = new BButton(viewframe, "okButton", "OK",
		new BMessage(B_QUIT_REQUESTED));
	mOkButton->MakeDefault(true);
	mOkButton->GetPreferredSize(&vw, &vh);
	mOkButton->ResizeTo(vw, vh);
	mOkButton->MoveTo(frame.right - vw - 8.0f,
		frame.bottom - vh - 8.0f);
	AddChild(mOkButton);
	
	float cw, ch;
	mCancelButton = new BButton(viewframe, "cancelButton", "Cancel",
		new BMessage(B_QUIT_REQUESTED));
	mCancelButton->GetPreferredSize(&cw, &ch);
	mCancelButton->ResizeTo(cw, ch);
	mCancelButton->MoveTo(frame.right - vw - 16.0f - cw,
		frame.bottom - ch - 8.0f);
	AddChild(mCancelButton);
	
} // end CalcOptionsWindow::CalcOptionsWindow()

 
/*******************************************************************************
<func>
Class:		CalcOptionsWindow
Function:	virtual ~CalcOptionsWindow();
Summary:	Destructor.
Params:	
Returns:	
Author:		timmy
Created:	1997.10.25
Notes:		-
History:
19971028 timmy Added code to save the current options.
</func>
*******************************************************************************/
CalcOptionsWindow::~CalcOptionsWindow(){

	// auto num-lock
	if (mAutoNumLockCheckBox->Value() == B_CONTROL_ON)
		mOptions->mAutoNumLock = true;
	else
		mOptions->mAutoNumLock = false;

	// audio feedback
	if (mAudioFeedbackCheckBox->Value() == B_CONTROL_ON)
		mOptions->mAudioFeedback = true;
	else
		mOptions->mAudioFeedback = false;

} // end CalcOptionsWindow::~CalcOptionsWindow()


/*******************************************************************************
<func>
Class:		CalcOptionsWindow
Function:	bool QuitRequested();
Summary:	Quit requested hook.
Params:	
Returns:	
Author:		timmy
Created:	1997.10.25
Notes:		-
History:
</func>
*******************************************************************************/
bool CalcOptionsWindow::QuitRequested(){

	return true;

} // end CalcOptionsWindow::QuitRequested()


/******************************************************************************/

// end CalcOptionsWindow.cpp
